class: Workflow
cwlVersion: v1.2.0-dev2
doc: 'Abstract CWL Automatically generated from the Galaxy workflow file: Genome-wide
  alternative splicing analysis'
inputs:
  CPAT_header_tab:
    format: data
    type: File
  GRCh38_p13_genome_fa_gz:
    format: data
    type: File
  Input Dataset Collection:
    format: data
    type: File
  Pfam-A_hmm_dat_gz:
    format: data
    type: File
  Pfam-A_hmm_gz:
    format: data
    type: File
  active_site_dat_gz:
    format: data
    type: File
  gencode_v43_annotation_gtf_gz:
    format: data
    type: File
  gencode_v43_lncRNA_transcripts_fa_gz:
    format: data
    type: File
  gencode_v43_pc_transcripts_fa_gz:
    format: data
    type: File
  gencode_v43_transcripts_fa_gz:
    format: data
    type: File
outputs: {}
steps:
  10_Convert GTF to BED12:
    in:
      gtf_file: gencode_v43_annotation_gtf_gz
    out:
    - bed_file
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_gtftobed12_gtftobed12_357
      inputs:
        gtf_file:
          format: Any
          type: File
      outputs:
        bed_file:
          doc: bed12
          type: File
  11_fastp:
    in:
      single_paired|paired_input: Input Dataset Collection
    out:
    - output_paired_coll
    - report_html
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_fastp_fastp_0_23_2+galaxy0
      inputs:
        single_paired|paired_input:
          format: Any
          type: File
      outputs:
        output_paired_coll:
          doc: input
          type: File
        report_html:
          doc: html
          type: File
  12_Flatten collection:
    in:
      input: Input Dataset Collection
    out:
    - output
    run:
      class: Operation
      id: __FLATTEN__
      inputs:
        input:
          format: Any
          type: File
      outputs:
        output:
          doc: input
          type: File
  13_RNA STAR:
    in:
      refGenomeSource|GTFconditional|sjdbGTFfile: gencode_v43_annotation_gtf_gz
      refGenomeSource|genomeFastaFiles: GRCh38_p13_genome_fa_gz
      singlePaired|input: 11_fastp/output_paired_coll
    out:
    - output_log
    - splice_junctions
    - mapped_reads
    - signal_unique_str1
    - signal_uniquemultiple_str1
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_rgrnastar_rna_star_2_7_10b+galaxy3
      inputs:
        refGenomeSource|GTFconditional|sjdbGTFfile:
          format: Any
          type: File
        refGenomeSource|genomeFastaFiles:
          format: Any
          type: File
        singlePaired|input:
          format: Any
          type: File
      outputs:
        mapped_reads:
          doc: bam
          type: File
        output_log:
          doc: txt
          type: File
        signal_unique_str1:
          doc: bedgraph
          type: File
        signal_uniquemultiple_str1:
          doc: bedgraph
          type: File
        splice_junctions:
          doc: interval
          type: File
  14_FastQC:
    in:
      input_file: 12_Flatten collection/output
    out:
    - html_file
    - text_file
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_devteam_fastqc_fastqc_0_73+galaxy0
      inputs:
        input_file:
          format: Any
          type: File
      outputs:
        html_file:
          doc: html
          type: File
        text_file:
          doc: txt
          type: File
  15_StringTie:
    in:
      guide|guide_source|ref_hist: gencode_v43_annotation_gtf_gz
      input_options|input_bam: 13_RNA STAR/mapped_reads
    out:
    - output_gtf
    - exon_expression
    - intron_expression
    - transcript_expression
    - exon_transcript_mapping
    - intron_transcript_mapping
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_stringtie_stringtie_2_2_1+galaxy1
      inputs:
        guide|guide_source|ref_hist:
          format: Any
          type: File
        input_options|input_bam:
          format: Any
          type: File
      outputs:
        exon_expression:
          doc: tabular
          type: File
        exon_transcript_mapping:
          doc: tabular
          type: File
        intron_expression:
          doc: tabular
          type: File
        intron_transcript_mapping:
          doc: tabular
          type: File
        output_gtf:
          doc: gtf
          type: File
        transcript_expression:
          doc: tabular
          type: File
  16_Junction Annotation:
    in:
      input: 13_RNA STAR/mapped_reads
      refgene: 10_Convert GTF to BED12/bed_file
    out:
    - outputpdf
    - outputjpdf
    - outputxls
    - stats
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_nilesh_rseqc_rseqc_junction_annotation_5_0_1+galaxy2
      inputs:
        input:
          format: Any
          type: File
        refgene:
          format: Any
          type: File
      outputs:
        outputjpdf:
          doc: pdf
          type: File
        outputpdf:
          doc: pdf
          type: File
        outputxls:
          doc: tabular
          type: File
        stats:
          doc: txt
          type: File
  17_Infer Experiment:
    in:
      input: 13_RNA STAR/mapped_reads
      refgene: 10_Convert GTF to BED12/bed_file
    out:
    - output
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_nilesh_rseqc_rseqc_infer_experiment_5_0_1+galaxy2
      inputs:
        input:
          format: Any
          type: File
        refgene:
          format: Any
          type: File
      outputs:
        output:
          doc: txt
          type: File
  18_Read Distribution:
    in:
      input: 13_RNA STAR/mapped_reads
      refgene: 10_Convert GTF to BED12/bed_file
    out:
    - output
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_nilesh_rseqc_rseqc_read_distribution_5_0_1+galaxy2
      inputs:
        input:
          format: Any
          type: File
        refgene:
          format: Any
          type: File
      outputs:
        output:
          doc: txt
          type: File
  19_Gene Body Coverage (BAM):
    in:
      batch_mode|input: 13_RNA STAR/mapped_reads
      refgene: 10_Convert GTF to BED12/bed_file
    out:
    - outputcurvespdf
    - outputtxt
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_nilesh_rseqc_rseqc_geneBody_coverage_5_0_1+galaxy2
      inputs:
        batch_mode|input:
          format: Any
          type: File
        refgene:
          format: Any
          type: File
      outputs:
        outputcurvespdf:
          doc: pdf
          type: File
        outputtxt:
          doc: txt
          type: File
  20_Junction Saturation:
    in:
      input: 13_RNA STAR/mapped_reads
      refgene: 10_Convert GTF to BED12/bed_file
    out:
    - outputpdf
    - outputr
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_nilesh_rseqc_rseqc_junction_saturation_5_0_1+galaxy2
      inputs:
        input:
          format: Any
          type: File
        refgene:
          format: Any
          type: File
      outputs:
        outputpdf:
          doc: pdf
          type: File
        outputr:
          doc: txt
          type: File
  21_MultiQC:
    in:
      results_0|software_cond|output_0|input: 14_FastQC/text_file
    out:
    - stats
    - html_report
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_multiqc_multiqc_1_11+galaxy1
      inputs:
        results_0|software_cond|output_0|input:
          format: Any
          type: File
      outputs:
        html_report:
          doc: html
          type: File
        stats:
          doc: input
          type: File
  22_Extract element identifiers:
    in:
      input_collection: 15_StringTie/transcript_expression
    out:
    - output
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_collection_element_identifiers_collection_element_identifiers_0_0_2
      inputs:
        input_collection:
          format: Any
          type: File
      outputs:
        output:
          doc: txt
          type: File
  23_MultiQC:
    in:
      results_0|software_cond|output_0|type|input: 13_RNA STAR/output_log
      results_1|software_cond|output_0|type|input: 17_Infer Experiment/output
      results_1|software_cond|output_1|type|input: 18_Read Distribution/output
      results_1|software_cond|output_2|type|input: 20_Junction Saturation/outputr
      results_1|software_cond|output_3|type|input: 16_Junction Annotation/stats
      results_1|software_cond|output_4|type|input: 19_Gene Body Coverage (BAM)/outputtxt
    out:
    - stats
    - html_report
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_multiqc_multiqc_1_11+galaxy1
      inputs:
        results_0|software_cond|output_0|type|input:
          format: Any
          type: File
        results_1|software_cond|output_0|type|input:
          format: Any
          type: File
        results_1|software_cond|output_1|type|input:
          format: Any
          type: File
        results_1|software_cond|output_2|type|input:
          format: Any
          type: File
        results_1|software_cond|output_3|type|input:
          format: Any
          type: File
        results_1|software_cond|output_4|type|input:
          format: Any
          type: File
      outputs:
        html_report:
          doc: html
          type: File
        stats:
          doc: input
          type: File
  24_Search in textfiles:
    in:
      infile: 22_Extract element identifiers/output
    out:
    - output
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_bgruening_text_processing_tp_grep_tool_1_1_1
      inputs:
        infile:
          format: Any
          type: File
      outputs:
        output:
          doc: input
          type: File
  25_Filter collection:
    in:
      how|filter_source: 24_Search in textfiles/output
      input: 15_StringTie/transcript_expression
    out:
    - output_filtered
    - output_discarded
    run:
      class: Operation
      id: __FILTER_FROM_FILE__
      inputs:
        how|filter_source:
          format: Any
          type: File
        input:
          format: Any
          type: File
      outputs:
        output_discarded:
          doc: input
          type: File
        output_filtered:
          doc: input
          type: File
  26_IsoformSwitchAnalyzeR:
    in:
      functionMode|first_factor|trans_counts: 25_Filter collection/output_filtered
      functionMode|genomeAnnotation: gencode_v43_annotation_gtf_gz
      functionMode|second_factor|trans_counts: 25_Filter collection/output_discarded
      functionMode|transcriptome: gencode_v43_transcripts_fa_gz
    out:
    - switchList
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_isoformswitchanalyzer_isoformswitchanalyzer_1_20_0+galaxy0
      inputs:
        functionMode|first_factor|trans_counts:
          format: Any
          type: File
        functionMode|genomeAnnotation:
          format: Any
          type: File
        functionMode|second_factor|trans_counts:
          format: Any
          type: File
        functionMode|transcriptome:
          format: Any
          type: File
      outputs:
        switchList:
          doc: rdata
          type: File
  27_IsoformSwitchAnalyzeR:
    in:
      functionMode|robject: 26_IsoformSwitchAnalyzeR/switchList
    out:
    - switchList
    - isoformAA
    - isoformNT
    - switchSummary
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_isoformswitchanalyzer_isoformswitchanalyzer_1_20_0+galaxy0
      inputs:
        functionMode|robject:
          format: Any
          type: File
      outputs:
        isoformAA:
          doc: fasta
          type: File
        isoformNT:
          doc: fasta
          type: File
        switchList:
          doc: rdata
          type: File
        switchSummary:
          doc: tabular
          type: File
  28_CPAT:
    in:
      c: gencode_v43_pc_transcripts_fa_gz
      gene: 27_IsoformSwitchAnalyzeR/isoformNT
      n: gencode_v43_lncRNA_transcripts_fa_gz
      r: GRCh38_p13_genome_fa_gz
    out:
    - orf_seqs
    - orf_seqs_prob
    - orf_seqs_prob_best
    - no_orf_seqs
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_bgruening_cpat_cpat_3_0_4+galaxy0
      inputs:
        c:
          format: Any
          type: File
        gene:
          format: Any
          type: File
        n:
          format: Any
          type: File
        r:
          format: Any
          type: File
      outputs:
        no_orf_seqs:
          doc: txt
          type: File
        orf_seqs:
          doc: fasta
          type: File
        orf_seqs_prob:
          doc: tsv
          type: File
        orf_seqs_prob_best:
          doc: tsv
          type: File
  29_PfamScan:
    in:
      active_sites|active_file: active_site_dat_gz
      fasta: 27_IsoformSwitchAnalyzeR/isoformAA
      pfam_data: Pfam-A_hmm_dat_gz
      pfam_library: Pfam-A_hmm_gz
    out:
    - output
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_bgruening_pfamscan_pfamscan_1_6+galaxy0
      inputs:
        active_sites|active_file:
          format: Any
          type: File
        fasta:
          format: Any
          type: File
        pfam_data:
          format: Any
          type: File
        pfam_library:
          format: Any
          type: File
      outputs:
        output:
          doc: tabular
          type: File
  30_Remove beginning:
    in:
      input: 28_CPAT/orf_seqs_prob_best
    out:
    - out_file1
    run:
      class: Operation
      id: Remove_beginning1
      inputs:
        input:
          format: Any
          type: File
      outputs:
        out_file1:
          doc: input
          type: File
  31_Text reformatting:
    in:
      infile: 30_Remove beginning/out_file1
    out:
    - outfile
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_bgruening_text_processing_tp_awk_tool_1_1_2
      inputs:
        infile:
          format: Any
          type: File
      outputs:
        outfile:
          doc: input
          type: File
  32_Concatenate datasets:
    in:
      inputs: CPAT_header_tab
      queries_0|inputs2: 31_Text reformatting/outfile
    out:
    - out_file1
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_bgruening_text_processing_tp_cat_0_1_1
      inputs:
        inputs:
          format: Any
          type: File
        queries_0|inputs2:
          format: Any
          type: File
      outputs:
        out_file1:
          doc: input
          type: File
  33_IsoformSwitchAnalyzeR:
    in:
      functionMode|coding_potential|analyzeCPAT: 32_Concatenate datasets/out_file1
      functionMode|protein_domains|analyzePFAM: 29_PfamScan/output
      functionMode|robject: 27_IsoformSwitchAnalyzeR/switchList
    out:
    - plots_summary
    - genes_consequences
    - genes_wo_consequences
    - switchList
    - mostSwitching
    - consequencesSummary
    - consequencesEnrichment
    - splicingSummary
    - splicingEnrichment
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_isoformswitchanalyzer_isoformswitchanalyzer_1_20_0+galaxy0
      inputs:
        functionMode|coding_potential|analyzeCPAT:
          format: Any
          type: File
        functionMode|protein_domains|analyzePFAM:
          format: Any
          type: File
        functionMode|robject:
          format: Any
          type: File
      outputs:
        consequencesEnrichment:
          doc: tabular
          type: File
        consequencesSummary:
          doc: tabular
          type: File
        genes_consequences:
          doc: input
          type: File
        genes_wo_consequences:
          doc: input
          type: File
        mostSwitching:
          doc: tabular
          type: File
        plots_summary:
          doc: input
          type: File
        splicingEnrichment:
          doc: tabular
          type: File
        splicingSummary:
          doc: tabular
          type: File
        switchList:
          doc: rdata
          type: File
  34_IsoformSwitchAnalyzeR:
    in:
      functionMode|coding_potential|analyzeCPAT: 32_Concatenate datasets/out_file1
      functionMode|protein_domains|analyzePFAM: 29_PfamScan/output
      functionMode|robject: 27_IsoformSwitchAnalyzeR/switchList
    out:
    - switchList
    - single_gene
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_isoformswitchanalyzer_isoformswitchanalyzer_1_20_0+galaxy0
      inputs:
        functionMode|coding_potential|analyzeCPAT:
          format: Any
          type: File
        functionMode|protein_domains|analyzePFAM:
          format: Any
          type: File
        functionMode|robject:
          format: Any
          type: File
      outputs:
        single_gene:
          doc: pdf
          type: File
        switchList:
          doc: rdata
          type: File

